@@ -13,7 +13,8 @@ use strict;
 use Carp;
 use Data::Table::Text qw(:all);
 use Digest::SHA qw(sha256_hex);
-our $VERSION = 2017.716;
+use Encode;
+our $VERSION = 2017.717;
 
 #1 Constructor                                                                  # Construct a new linter
 
@@ -65,7 +66,7 @@ sub lint($@)
   $attributes{catalog} = $C if $C;
   $attributes{dtds}    = $d if $d;
   $attributes{project} = $P if $P;
-  $attributes{sha256}  = sha256_hex($lint->source);                             # Digest of text
+  $attributes{sha256} = sha256_hex(encode("ascii", $lint->source));             # Digest of source string
 
   my $a = sub                                                                   # Attributes to be recorded with the xml
    {my @s;
@@ -564,7 +565,7 @@ if (1)
 <concept id="$project">
  <title>Project $project</title>
  <conbody>
-   <p>Body of $project</p>
+   <p>Body of $project 𝝰</p>
  </conbody>
 </concept>
 END
